/* gnome-theme-installer.h
 * Copyright (C) 2002 Jonathan Blandford 
 *
 * Written by: Jonathan Blandford <jrb@gnome.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef GNOME_THEME_INSTALLER_H
#define GNOME_THEME_INSTALLER_H

#include <gtk/gtk.h>

void gnome_theme_install_from_uri (gchar * filename, GtkWindow *parent);

void gnome_theme_installer_run (GtkWindow *parent, gchar *filename);
void gnome_theme_installer_run_cb (GtkWidget *button, GtkWindow *parent_window);

#endif /* GNOME_THEME_INSTALLER_H */
